/*+++++++++++++
.TYPE           Module
.IDENTIFICATION jgal.c
.VERSION 1.0	27-Feb-1987: Creation
.VERSION 1.1	24-Oct-1988: Applies on Unit Vectors
.VERSION 2.0	22-Feb-1991: Tested on PCs with TuboC
.LANGUAGE       C
.AUTHOR         Francois Ochsenbein [ESO-IPG]  
.KEYWORDS       J2000 / Galactic coordinate transformations
.COMMENTS
All spherical coordinates are assumed to be expressed in DEGREES.
No function is traced.

\begin{TeX}

The parameter mnemonics are:

\begin{itemize}
 \item f = array $[\alpha,\delta]$ of  Fundamental (J2000) equatorial coordinates 
 \item g = array $[\ell,b]$    of  Galactic   coordinates
\end{itemize}
\end{TeX}

-----------------------------------------------------------------------*/
 

#include <astropos.h>

double gal_2000[3][3] = {	/* J2000 to galactic rotation matrix */
     	{-0.054875539726e0, -0.873437108010e0, -0.483834985808e0},
     	{ 0.494109453312e0, -0.444829589425e0,  0.746982251810e0},
     	{-0.867666135858e0, -0.198076386122e0,  0.455983795705e0}
	};

/*============================================================================*/
int tr_f5g (uf5 , ug)  
/*+++
.PURPOSE   transformation from J2000 to Galactic 
.RETURNS   1
---*/
	double uf5[3];  /* IN: J2000 Unit Vector */
	double ug[3];  	/* OUT: Galactic Unit Vector */
{ 
  return (tr_uu ( uf5, ug, gal_2000));
}

/*============================================================================*/
int tr_gf5 (ug , uf5)  
/*+++	
.PURPOSE  transformation from Galactic to J2000
.RETURNS  1
---*/
	double ug[3]; 	/* IN: Galactic Unit Vector 	*/
	double uf5[3];   /* OUT: J2000 Unit Vector	*/
{ 
  return (tr_uu1 ( ug, uf5, gal_2000));
}

