/*+++	Trigonometric Function in degrees
.TYPE		Module
.IDENTIFICATION	trigoc.c
.LANGUAGE	C
.AUTHOR		Francois Ochsenbein [ESO-IPG]
.CATEGORY	Special Functions using trigonometry
.COMMENTS	Arguments in RADIANS

.VERSION  1.0	09-Sep-1988: Creation
.VERSION  2.0	22-Feb-1991: Tested on PCs with TuboC
.VERSION  2.1	28-Feb-2001: asinc has a problem !!
________________________________________*/

#include <math.h>	


/*=========================================================================
 *			sinc
 *=========================================================================*/
double sinc (x)
/*+++
.DES Computation of sin(x)/x
.RET value
.METHOD 
\begin{TeX}
For small argument ($x \leq 10^{-3}$), use approximation 
	$$ {\rm sinc} x = 1 - \frac{x^2}{3!} + \frac{x^4}{5!} $$
\end{TeX}

---*/
  	double x;      /* IN: argument in degrees */
{ 
	double ax, y;
	
  ax = fabs(x);

  if (ax <= 0.01) {
  	ax *= ax, 
  	y = 1 - ax*(1.e0-ax/20.e0)/6.e0;
  }
  else	y = sin(ax)/ax;

  return (y);
}

/*=========================================================================
 *			asinc
 *=========================================================================*/
double asinc(x)
/*+++
.DES Computes asin(x)/x
.RET value
.METHOD 
\begin{TeX}
For small argument ($x \leq 10^{-3}$), use approximation 
	$$ {\rm asinc} x = 1 + \frac{x^2}{6} + \frac{3x^4}{40} $$
	The full development of the Asin(x)/x function is
	$$ {\rm asinc} x = \sum_0^\infty\frac{1\cdot3\cdot5\cdots(2n-1)}
	   {2\cdot4\cdot6\cdots(2n)} \quad \frac{x^{2n}}{2n+1}	$$
\end{TeX}
---*/
  	double x;      /* argument in degrees */
{ 
	double ax, y;
	
  ax = fabs(x);

  if (ax <= 0.01) {
  	ax *= ax, 
  	y = 1 + ax*(1.e0 + ax*(9.e0/20.e0 + ax*(15./56.)))/6.e0;
  }
  else	y = asin(ax)/ax;

  return (y);
}

